const allCopyBtn = document.querySelector(".all-copy");
const copyBtn = document.createElement("div");
copyBtn.classList.add("copy-button");
const copyBtnHtml = `
<svg xmlns="http://www.w3.org/2000/svg" width="19" height="18" viewBox="0 0 19 18" fill="none">
  <path d="M14.375 1.5H7.625C6.8 1.5 6.125 2.175 6.125 3V12C6.125 12.825 6.8 13.5 7.625 13.5H14.375C15.2 13.5 15.875 12.825 15.875 12V3C15.875 2.175 15.2 1.5 14.375 1.5ZM14.375 12H7.625V3H14.375V12ZM3.125 11.25V9.75H4.625V11.25H3.125ZM3.125 7.125H4.625V8.625H3.125V7.125ZM8.375 15H9.875V16.5H8.375V15ZM3.125 13.875V12.375H4.625V13.875H3.125ZM4.625 16.5C3.8 16.5 3.125 15.825 3.125 15H4.625V16.5ZM7.25 16.5H5.75V15H7.25V16.5ZM11 16.5V15H12.5C12.5 15.825 11.825 16.5 11 16.5ZM4.625 4.5V6H3.125C3.125 5.175 3.8 4.5 4.625 4.5Z" fill="#CECECE"/>
</svg>
`;

copyBtn.innerHTML = copyBtnHtml;

document.querySelector("form").addEventListener("submit", function (event) {
  event.preventDefault();

  const fields = [
    "article-type",
    "article-url",
    "headline",
    "description",
    "image-url",
    "image-width",
    "image-height",
    "author-type",
    "author-name",
    "author-url",
    "publisher-name",
    "logo-url",
    "logo-width",
    "logo-height",
    "date-published",
    "date-modified",
  ];

  let fieldValues = {};
  fields.forEach(function (field) {
    if (field === "date-published" || field === "date-modified") {
      const dateStr = document.getElementById(field).value;
      const date = new Date(dateStr);
      const isoStr = date.toISOString();

      fieldValues[field] = isoStr;
    } else {
      fieldValues[field] = document.getElementById(field).value;
    }
  });

  let schema = {
    "@context": "https://schema.org/",
    "@type": fieldValues["article-type"],
    headline: fieldValues["headline"],
    description: fieldValues["description"],
    url: fieldValues["article-url"],
    image: {
      "@type": "ImageObject",
      url: fieldValues["image-url"],
      width: Number(fieldValues["image-width"]),
      height: Number(fieldValues["image-height"]),
    },
    author: {
      "@type": fieldValues["author-type"],
      name: fieldValues["author-name"],
      url: fieldValues["author-url"],
    },
    publisher: {
      "@type": "Organization",
      name: fieldValues["publisher-name"],
      logo: {
        "@type": "ImageObject",
        url: fieldValues["logo-url"],
        width: Number(fieldValues["logo-width"]),
        height: Number(fieldValues["logo-height"]),
      },
    },
    datePublished: fieldValues["date-published"],
    dateModified: fieldValues["date-modified"],
  };

  const prettySchema = JSON.stringify(schema, null, 4);
  const preElement = document.createElement("pre");
  const codeElement = document.createElement("code");

  preElement.appendChild(codeElement);

  codeElement.textContent = `
  <script type="application/ld+json">
  ${prettySchema}
  </script>
  `;

  const newOutputNode = document.createElement("div");
  newOutputNode.id = "output";
  newOutputNode.appendChild(preElement);

  const oldOutputNode = document.querySelector("#output");
  document
    .getElementById("output-area-container")
    .replaceChild(newOutputNode, oldOutputNode);

  hljs.highlightAll();

  allCopyBtn.classList.remove("hidden");
  allCopyBtn.innerHTML = copyBtnHtml + `<p>Copy</p>`;
});
