import populateAboutArea from "../globaljs/populate-about-area.js";
import generateFAQ from "../globaljs/faqGenerator.js";

const aboutData = [
  [
    "What is an Article Summary Generator?",
    `
    <p>An Article Summary Generator is like a helpful assistant for reading. Imagine you have a long article, and you want to know what it's about without reading the whole thing. This tool does that for you! It takes the article, looks at the main points, and gives you a short version of it. It's like getting the highlights without spending a lot of time. This is super handy for people who are busy, like students or writers, or anyone who just wants to get to the main idea quickly.</p>
    `,
  ],
  [
    "Why Use an Article Summary Generator?",
    `
    <p>The benefits of using an Article Summary Generator are manifold. Let's dive into why it's becoming indispensable.</p>
    <ul>
      <li><strong>Time-Saving:</strong> Gone are the days of sifting through pages. Get the essence in moments.</li>
      <li><strong>Consistency:</strong> Every summary follows a uniform structure, simplifying content comparison.</li>
      <li><strong>Enhanced Understanding:</strong> Complex jargon? Lengthy explanations? The generator breaks them down for easy understanding.</li>
      <li><strong>Research Made Easy:</strong> Summarize multiple articles in a snap, making research a breeze.</li>
    </ul>
    `,
  ],
  [
    "How Article Summary Generator Works?",
    `
    <p>The magic of an Article Summary Generator lies in its ability to distill vast amounts of information into concise summaries. But how does it achieve this feat? Let's break it down step by step:</p>
    <ol>
      <li><strong>Input & Pre-processing:</strong> The journey begins when you feed the generator with the article you want to summarize. The tool first pre-processes this data by:
        <ul>
          <li>Removing any irrelevant content like ads or sidebars.</li>
          <li>Tokenizing the content, which means breaking it down into individual words or phrases.</li>
          <li>Identifying the structure of the content, such as headings, subheadings, and paragraphs.</li>
        </ul>
      </li>
      <li><strong>Natural Language Processing (NLP):</strong> At the heart of the generator lies NLP, a branch of artificial intelligence that helps machines understand and respond to human language. With NLP, the tool can:
        <ul>
          <li>Recognize the context and semantics of the content.</li>
          <li>Identify key themes, main ideas, and relevant details.</li>
          <li>Understand the sentiment and tone of the article.</li>
        </ul>
      </li>
      <li><strong>Extraction & Abstraction:</strong> There are primarily two methods the tool might use to create summaries:
        <ul>
          <li><strong>Extraction:</strong> This method involves pulling out key sentences or phrases directly from the original content. It's like highlighting the most important parts of an article.</li>
          <li><strong>Abstraction:</strong> This is a more advanced method where the tool rephrases or rewrites parts of the content to create a new, concise summary. It's akin to reading an article and then explaining it in your own words.</li>
        </ul>
      </li>
      <li><strong>Optimization & Refinement:</strong> Once the initial summary is generated, the tool refines it by:
        <ul>
          <li>Ensuring it's coherent and flows naturally.</li>
          <li>Removing any redundancy or repetition.</li>
          <li>Making sure the summary maintains the original intent and meaning of the article.</li>
        </ul>
      </li>
      <li><strong>Output:</strong> Finally, the tool presents you with a well-structured, concise summary of the original article. This summary retains the essence of the content, ensuring you get a clear understanding without having to read through lengthy texts.</li>
    </ol>
    `,
  ],
  [
    "How to Create an Article Summary With This Generator",
    `
    <p>Creating a summary is as easy as pie. Here's a step-by-step guide to get you started.</p>
    <ol>
      <li><strong>Visit the Tool's Website:</strong> Begin by heading over to the generator's official website. Most of these platforms have a clean and user-friendly interface, making it a breeze even for first-time users.</li>
      <li><strong>Paste Your Article:</strong> Once you're on the platform, you'll typically find a large text box or area. This is where you input your article. Just copy the content you want to summarize from its source and paste it right there.</li>
      <li><strong>Choose Length:</strong> One of the best features of many summary generators is the ability to customize the length of the summary. Depending on the tool, you might find options like 'short', 'medium', or 'long', or you might be able to specify the number of sentences or words you want. Choose what fits your needs best.</li>
      <li><strong>Generate:</strong> After setting your preferences, it's time to let the tool work its magic. Simply click on the 'Generate' button, usually prominently displayed. In a matter of seconds, the tool will analyze your content and provide a summarized version.</li>
      <li><strong>Review & Edit:</strong> While these generators are pretty smart, they're not infallible. It's always a good idea to read through the generated summary. Check for clarity, accuracy, and coherence. Sometimes, adding a human touch can make the summary even better. Adjust any parts that seem off or add any crucial points you feel might have been missed.</li>
    </ol>
    `,
  ],
  [
    "Importance of Article Summary",
    `
    <p>Ever pondered why article summaries are gaining traction? Let's delve into their significance.</p>
    <ul>
      <li><strong>Efficiency for Readers:</strong> No more wading through verbose content. Get the gist in a jiffy.</li>
      <li><strong>Boosts Engagement:</strong> A tantalizing summary can pique curiosity, leading readers to the full article.</li>
      <li><strong>SEO Perks:</strong> Rich snippets in the form of summaries can enhance search visibility.</li>
      <li><strong>Versatility:</strong> Perfect for presentations, reports, or sharing on social platforms.</li>
    </ul>
    `,
  ],
];

const faqData = [
  [
    "How dependable is the Article Summary Generator?",
    "Our generator is technologically advanced and provides accurate summaries. However, it's always recommended to review the output to ensure it aligns with the article's core message."
  ],
  [
    "Is the Article Summary Generator suitable for academic articles?",
    "Yes, it's designed to handle academic content. However, for academic precision, always review the generated summary to ensure all critical points are covered."
  ],
  [
    "Does the Article Summary Generator have a word limit for processing articles?",
    "While our generator is robust and can handle extensive articles, it's advisable to check specific tool capacities as some might have limitations on the number of words they can process at once."
  ]
];

populateAboutArea(aboutData);
generateFAQ(faqData);
