import populateAboutArea from "../globaljs/populate-about-area.js";
import generateFAQ from "../globaljs/faqGenerator.js";

const aboutData = [
  [
    "What is a Business Name Generator?",
    `
    <p>A Business Name Generator is a specialized tool designed to take the stress out of naming your business. It's a digital solution, either software or an online service, that generates unique and relevant business name suggestions based on your input, preferences, or industry.</p>
    <p>These generators employ intelligent algorithms and domain availability checks to provide you with a list of potential business names.</p>
    `,
  ],
  [
    "Why Use a Business Name Generator?",
    `
    <p>So, why should you use a Business Name Generator? Here's why:</p>
    <ul>
      <li><strong>Time Efficiency:</strong> Say goodbye to endless hours of brainstorming; a Business Name Generator can churn out a multitude of options in mere seconds, saving you valuable time.</li>
      <li><strong>Creative Spark:</strong> These tools can ignite your creativity by proposing inventive combinations and variations you might not have thought of.</li>
      <li><strong>Availability Checker:</strong> They swiftly verify if the suggested business names are available for registration, sparing you the frustration of discovering your desired name is already taken.</li>
      <li><strong>Brand Relevance:</strong> Some generators consider your industry and target audience, ensuring your business name aligns perfectly with your brand.</li>
    </ul>
    `,
  ],
  [
    "How Business Name Generator Works?",
    `
    <p>Behind the scenes, Business Name Generators employ advanced algorithms to generate relevant and catchy suggestions. Here's a simplified breakdown of their operation:</p>
    <ol>
      <li><strong>Keyword Input:</strong> You begin by entering keywords or phrases that are relevant to your business, products, or services. These keywords serve as the foundation for generating business name suggestions.</li>
      <li><strong>Creative Combos:</strong> The tool combines these keywords with various prefixes, suffixes, and domain extensions to produce a diverse range of business name possibilities.</li>
      <li><strong>Availability Check:</strong> For each suggestion, the generator performs an instantaneous availability check to confirm whether the business name is available for registration.</li>
      <li><strong>Filtering Options:</strong> Many Business Name Generators offer filtering options that allow you to refine your results based on parameters such as character length, domain extension, and keyword prominence.</li>
      <li><strong>Presenting Suggestions:</strong> You'll be presented with a list of potential business names, complete with availability status and supplementary information to aid your decision-making process.</li>
    </ol>
    `,
  ],
  [
    "How to Create a Business Name With This Generator",
    `
    <p>Now that you understand the mechanics of Business Name Generators, let's delve into the steps for crafting the perfect business name using one:</p>
    <ol>
      <li><strong>Keyword Entry:</strong> Start by inputting keywords or phrases that are directly related to your business's purpose, industry, or unique selling points. The more specific, the better.</li>
      <li><strong>Set Preferences:</strong> Some generators allow you to specify preferences, such as desired character length, industry relevance, or language.</li>
      <li><strong>Generate Suggestions:</strong> Activate the generator by clicking the "Generate" or "Search" button, and let the magic unfold. The generator will swiftly compile a list of potential business names for you.</li>
      <li><strong>Review and Refine:</strong> Take your time to assess the suggestions. Pay attention to factors like memorability, uniqueness, and relevance to your brand. Filters can help you narrow down your choices.</li>
      <li><strong>Check Availability:</strong> Once you've identified a business name that resonates with you, click on it to verify its availability. If it's accessible, you're one step closer to establishing your brand identity.</li>
      <li><strong>Register Your Business Name:</strong> If the selected business name is available, you can proceed to register it through a business registration service or your local authorities. Act promptly, as great business names can be claimed swiftly.</li>
    </ol>
    `,
  ],
  [
    "Importance of a Well-Crafted Business Name",
    `
    <p>Your business name isn't just a label; it's your brand's first impression and your customers' initial point of contact. Here's why selecting the right business name is pivotal:</p>
    <ul>
      <li><strong>Brand Identity:</strong> Your business name communicates your brand's essence, values, and mission, shaping how customers perceive you.</li>
      <li><strong>Memorability:</strong> A memorable business name is more likely to stick in the minds of potential customers, facilitating word-of-mouth marketing.</li>
      <li><strong>Relevance:</strong> A well-chosen business name is directly related to your industry and offerings, helping customers understand your business at a glance.</li>
      <li><strong>Distinctiveness:</strong> A unique name sets you apart from competitors, making it easier for customers to differentiate you from the crowd.</li>
      <li><strong>Longevity:</strong> A carefully chosen business name can stand the test of time, supporting your brand through various stages of growth.</li>
    </ul>
    `,
  ],
];

const businessNameGeneratorData = `
  <p>Choosing the right name for your business is a big decision. A business name generator simplifies this task. It uses keywords to create a list of potential names. This tool is fast and free.</p>
  <p>It offers creative options you might not think of. A good name sets the tone for your brand. It can tell a story in just a few words. A business name generator helps you start this story.</p>
  <p>It's a first step to a strong identity in the marketplace. Use it to find a name that stands out. It's the beginning of your business journey.</p>
  <p>In this article, we'll delve into the world of business name generation, exploring how it works, why it's vital for your brand's success, and how Onethread's tool simplifies the process.</p>
`;

const faqData = [
  [
    "Is the Business Name Generator available without any charges?",
    "Yes, our Business Name Generator provides a basic version for users at no cost. For those seeking more advanced functionalities, we do have premium options."
  ],
  [
    "Am I allowed to adjust the business name suggestions provided by the generator?",
    "Absolutely! Our generator's suggestions are meant to inspire and guide. You're encouraged to adapt these names to resonate with your brand's vision and values."
  ],
  [
    "What should I do if my chosen business name is already in use?",
    "If your ideal business name is taken, you might consider creative alternatives like incorporating synonyms, adding unique elements, or even considering different domain extensions. Alternatively, you could reach out to the current owner to discuss potential acquisition or licensing options."
  ],
  [
    "How important is it to secure a .com domain for my business?",
    "While .com domains are widely recognized, the best domain extension for your business should reflect its nature and target audience. Extensions like .net, .biz, or industry-specific ones might be just as effective, depending on your business objectives."
  ]
];

populateAboutArea(aboutData, businessNameGeneratorData);
generateFAQ(faqData);
