import populateAboutArea from "../globaljs/populate-about-area.js";
import generateFAQ from "../globaljs/faqGenerator.js";

const aboutData = [
  [
    "What is an Event Name Generator?",
    `
    <p>An Event Name Generator is a powerful tool designed to simplify the process of brainstorming and creating captivating names for your events. Here are its key features:</p>
    <ul>
      <li><strong>Creativity Spark:</strong> The Event Name Generator sparks creativity by providing you with a wide range of event name suggestions.</li>
      <li><strong>Relevance:</strong> It ensures that the generated event names align with the theme, purpose, and target audience of your event.</li>
      <li><strong>Efficiency:</strong> Event name brainstorming can be time-consuming. The generator streamlines the process, saving you valuable time.</li>
    </ul>
    `,
  ],
  [
    "Why Use an Event Name Generator?",
    `
    <p>Let's explore why integrating an Event Name Generator into your event planning toolkit is a game-changer:</p>
    <ul>
      <li><strong>Engagement Boost:</strong> Catchy event names pique curiosity and encourage potential attendees to learn more about your event.</li>
      <li><strong>Time and Effort Saved:</strong> Creating the perfect event name can be a daunting task. The generator eliminates the need for extensive brainstorming.</li>
      <li><strong>Consistency:</strong> If you're hosting multiple events, maintaining a consistent and memorable naming convention is crucial for brand recognition.</li>
      <li><strong>Inspiration:</strong> Even seasoned event organizers can hit creative roadblocks. The generator provides a wealth of fresh ideas to fuel your creativity.</li>
    </ul>
    `,
  ],
  [
    "How Event Name Generator Works?",
    `
    <p>Understanding the inner workings of an Event Name Generator is essential for maximizing its potential. Here's a closer look at how it operates:</p>
    <ol>
      <li><strong>Algorithm Initialization:</strong> At its core, an event name generator starts with an algorithm. This algorithm is often designed with linguistic rules, popular naming conventions, and sometimes even cultural or thematic relevance in mind.</li>
      <li><strong>User Input Analysis:</strong> When a user provides certain keywords or descriptors about their event, the generator assesses this data. For instance, if "beach" and "wedding" are entered, it recognizes the need for a relaxed, romantic, and perhaps tropical vibe.</li>
      <li><strong>Querying:</strong> Post analysis, the generator scours its internal database of words, phrases, and templates. This database houses a plethora of possible names, idioms, or even popular event-related jargon.</li>
      <li><strong>Name Construction:</strong> Using the initial input and the results from its database search, the generator constructs potential names. It can merge words, add prefixes or suffixes, or even utilize alliteration to make names catchy.</li>
      <li><strong>Relevance Check:</strong> The generator employs a filtering mechanism. It ensures that the names generated are not only unique but also relevant to the initial user input. Names that don't fit the criteria are discarded, ensuring a higher quality of suggestions.</li>
      <li><strong>Output Presentation:</strong> Once names are generated and filtered, they're presented to the user in a list format. Often, this list is sorted—either by relevance, popularity, or even by how trendy the naming convention is.</li>
      <li><strong>Feedback Loop:</strong> Some advanced generators have a feedback mechanism. If users often pick certain types of names or provide ratings, the generator learns and evolves. This ensures better name suggestions in future queries.</li>
    </ol>
    `,
  ],
  [
    "How to Create Event Names With This Generator",
    `
    <p>Generating event names with an Event Name Generator is a straightforward process. Here's a step-by-step guide:</p>
    <ol>
      <li><strong>Define Your Event:</strong> Begin by providing the generator with essential details about your event, such as its theme, purpose, and any specific keywords or preferences.</li>
      <li><strong>Generate Suggestions:</strong> Click the "Generate" button, and watch as the generator provides you with a selection of event name suggestions based on your input.</li>
      <li><strong>Review and Refine:</strong> Browse through the suggested event names and select the ones that resonate with your vision. You can then further refine and customize them to match your event's identity.</li>
      <li><strong>Select the Perfect Name:</strong> Once you've fine-tuned your event name, choose the one that captures the essence of your event and makes a memorable impact.</li>
    </ol>
    `,
  ],
  [
    "Importance of Engaging Event Names",
    `
    <p>The significance of crafting engaging event names cannot be overstated. Here's why they matter:</p>
    <ul>
      <li><strong>First Impressions:</strong> Event names are often the first point of contact potential attendees have with your event. A captivating name creates a positive first impression.</li>
      <li><strong>Curiosity and Interest:</strong> Intriguing event names pique curiosity and motivate individuals to explore further details about your event.</li>
      <li><strong>Branding:</strong> Consistent and memorable event names contribute to effective event branding and recognition.</li>
      <li><strong>Marketing Impact:</strong> Engaging event names enhance the effectiveness of your event marketing efforts, leading to increased attendance and engagement.</li>
      <li><strong>Memorability:</strong> A well-chosen event name is more likely to stick in the minds of your audience, making it easier for them to recall and share with others.</li>
    </ul>
    `,
  ],
];

const faqData = [
  [
    "Is using an Event Name Generator suitable for both large and small-scale events?",
    "Absolutely! Event Name Generators can be applied to events of all sizes, from intimate gatherings to grand-scale conferences and everything in between."
  ],
  [
    "What role do keywords play when using an Event Name Generator?",
    "Keywords are instrumental in shaping the suggestions generated by the tool. They help align event names with specific themes, target audiences, and objectives."
  ],
  [
    "Are there any copyright concerns when using event names generated by these tools?",
    "It's crucial to conduct a quick check to ensure that the generated event names are not trademarked or copyrighted by others. Most Event Name Generators provide guidance on this."
  ],
  [
    "Can I collaborate with a team to generate event names using these tools?",
    "Yes, many Event Name Generators offer collaborative features, allowing teams to brainstorm and refine event names together, streamlining the naming process."
  ]
];

populateAboutArea(aboutData);
generateFAQ(faqData);
