const returnAIResponse = async (
  prompt,
  isResponseMarkdown,
  usingMermaid,
  temperature = 1,
  userStraightLineInMermaid
) => {
  try {
    const response = await fetch("http://localhost:3000/", {
      body: JSON.stringify({
        input: prompt,
        temperature,
      }),
      headers: {
        "Content-Type": "application/json",
      },
      method: "POST",
    });

    if (!response.ok) {
      throw new Error(response.status);
    }

    const aiResponse = await response.json();

    if (usingMermaid) {
      if (userStraightLineInMermaid) {
        mermaid.initialize({
          startOnLoad: true,
          flowchart: { curve: "basis" },
        });
      } else {
        mermaid.initialize({
          startOnLoad: true,
        });
      }

      let graphDefinition = aiResponse
        .replace("```mermaid", "")
        .replace("```", "");

      let graph = await mermaid.render("graphDiv", graphDefinition);

      document.querySelector("#output").style.display = "block";
      document.querySelector("#output").innerHTML = graph.svg;
      return;
    }

    document.getElementById("output").innerHTML = isResponseMarkdown
      ? marked.parse(aiResponse)
      : aiResponse;
  } catch (err) {
    if (err.message === "500") {
      document.getElementById("output").textContent =
        "Something went wrong. Please try again later. Or, try decreasing your input length.";
    }

    if (err.message === "429") {
      document.getElementById("output").textContent = aiResponse.error;
      return;
    }
  }
};

export default returnAIResponse;
