import generate from "../globaljs/returnAIResponse.js";
import addClickEventToCopyButton from "../js/copyToClipboard.js";
import createDownloadFunctionalityForFlowchart from "./downloadFlowChart.js";

const copyBtn = document.createElement("div");
copyBtn.classList.add("copy-button");
const copyBtnHtml = `
<svg xmlns="http://www.w3.org/2000/svg" width="19" height="18" viewBox="0 0 19 18" fill="none">
  <path d="M14.375 1.5H7.625C6.8 1.5 6.125 2.175 6.125 3V12C6.125 12.825 6.8 13.5 7.625 13.5H14.375C15.2 13.5 15.875 12.825 15.875 12V3C15.875 2.175 15.2 1.5 14.375 1.5ZM14.375 12H7.625V3H14.375V12ZM3.125 11.25V9.75H4.625V11.25H3.125ZM3.125 7.125H4.625V8.625H3.125V7.125ZM8.375 15H9.875V16.5H8.375V15ZM3.125 13.875V12.375H4.625V13.875H3.125ZM4.625 16.5C3.8 16.5 3.125 15.825 3.125 15H4.625V16.5ZM7.25 16.5H5.75V15H7.25V16.5ZM11 16.5V15H12.5C12.5 15.825 11.825 16.5 11 16.5ZM4.625 4.5V6H3.125C3.125 5.175 3.8 4.5 4.625 4.5Z" fill="#CECECE"/>
</svg>
`;

copyBtn.innerHTML = copyBtnHtml;

const handleFormSubmit = (
  getFormValues,
  generatePrompt,
  isResponseMarkdown,
  usingMermaidJS,
  temperature,
  isHighlightJSUsed,
  useStraightLineInMermaid
) => {
  const form = document.querySelector("form");

  form.onsubmit = async function (e) {
    e.preventDefault();

    const stopBtnContainer = document.querySelector("#stop-btn-container");
    stopBtnContainer.classList.remove("hidden");

    const allCopyBtn = document.querySelector(".all-copy");
    if (!allCopyBtn.classList.contains("hidden")) {
      allCopyBtn.classList.add("hidden");
    }

    const generateBtn = document.querySelector("#generate");
    const generateBtnLoadingSvg = document.querySelector("#generate svg");
    generateBtnLoadingSvg.classList.remove("hidden");
    generateBtn.disabled = true;

    const downloadSvgIcon = document.querySelector(
      ".download-svg-icon-container"
    );
    if (downloadSvgIcon) {
      downloadSvgIcon.remove();
    }

    let flowchartActionContainer = document.querySelector(
      "#flowchart-action-container"
    );

    if (flowchartActionContainer) {
      flowchartActionContainer.remove();
    }

    const userInput = getFormValues();
    const prompt = generatePrompt(userInput);
    await generate(
      prompt,
      isResponseMarkdown,
      usingMermaidJS,
      temperature,
      isHighlightJSUsed,
      useStraightLineInMermaid
    );

    stopBtnContainer.classList.add("hidden");

    if (!usingMermaidJS) {
      allCopyBtn.classList.remove("hidden");
      allCopyBtn.innerHTML = copyBtnHtml + `<p>Copy</p>`;
    }

    generateBtnLoadingSvg.classList.add("hidden");
    generateBtn.disabled = false;

    if (isHighlightJSUsed) {
      const allCodeBlocks = document.querySelectorAll("pre");

      allCodeBlocks.forEach((block) => {
        const copyBtnClone = copyBtn.cloneNode(true); // because it is not possible to append the same element twice
        block.appendChild(copyBtnClone);
      });
      addClickEventToCopyButton();
    }

    if (usingMermaidJS) {
      createDownloadFunctionalityForFlowchart();

      flowchartActionContainer = document.querySelector(
        "#flowchart-action-container"
      );

      const fullScreenIconContainer = document.createElement("div");
      fullScreenIconContainer.innerHTML = `
      <svg height="14px" version="1.1" viewBox="0 0 14 14" width="14px" xmlns="http://www.w3.org/2000/svg" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns" xmlns:xlink="http://www.w3.org/1999/xlink"><title/><desc/><defs/><g fill="none" fill-rule="evenodd" id="Page-1" stroke="none" stroke-width="1"><g fill="white" id="Core" transform="translate(-215.000000, -257.000000)"><g id="fullscreen" transform="translate(215.000000, 257.000000)"><path d="M2,9 L0,9 L0,14 L5,14 L5,12 L2,12 L2,9 L2,9 Z M0,5 L2,5 L2,2 L5,2 L5,0 L0,0 L0,5 L0,5 Z M12,12 L9,12 L9,14 L14,14 L14,9 L12,9 L12,12 L12,12 Z M9,0 L9,2 L12,2 L12,5 L14,5 L14,0 L9,0 L9,0 Z" id="Shape"/></g></g></g></svg>
      `;
      fullScreenIconContainer.style.cursor = "pointer";

      fullScreenIconContainer.addEventListener("click", (e) => {
        const generatedFlowchart = document.querySelector("#output svg");

        generatedFlowchart.requestFullscreen({ navigationUI: "show" });
      });

      flowchartActionContainer.appendChild(fullScreenIconContainer);
    }
  };
};

export default handleFormSubmit;
