import { modifyTheConroller } from "./createOutputAreaDefaultDOM.js";

// const promptInput = document.getElementById("promptInput");
// const generateBtn = document.getElementById("generateBtn");
// const stopBtn = document.getElementById("stopBtn");
const output = document.querySelector("#output");

let contents = [];
const handleUsingMermaid = async (content, useStraightLineInMermaid) => {
  if (useStraightLineInMermaid) {
    mermaid.initialize({
      startOnLoad: true,
      curve: "basis",
      theme: "neutral",
      themeVariables: {
         lineColor: "gray",
      },
    });
  } else {
    mermaid.initialize({
      startOnLoad: true,
      theme: "neutral",
      themeVariables: {
        lineColor: "gray",
      },
    });
  }

  contents.push(content);

  const contentString = contents.join("");

  let graphDefinition = contentString
    .replace("```mermaid", "")
    .replace("```", "");

  if (
    (graphDefinition.endsWith("\n") || graphDefinition.at(-1) === ";") &&
    graphDefinition !== "\n"
  ) {
    try {
      await mermaid.render("graphDiv1", graphDefinition);
    } catch (error) {
      console.log("Parsing error:", error);
      return;
    }

    let graph = await mermaid.render("graphDiv", graphDefinition);
    document.querySelector("#output").style.display = "block";
    document.querySelector("#output").innerHTML = graph.svg;
  }
};

const handleMarkdownResponse = async (content, isHighlightJSUsed) => {
  marked.setOptions({
    mangle: false,
    headerIds: false,
  });

  contents.push(content);

  const contentString = contents.join("");
  document.querySelector("#output").innerHTML = marked.parse(contentString);

  if (isHighlightJSUsed) {
    hljs.highlightAll();
  }
};

const isJSON = (str) => {
  try {
    JSON.parse(str);
  } catch (e) {
    return false;
  }
  return true;
};

const generate = async (
  prompt,
  isResponseMarkdwown,
  usingMermaidJS,
  temperature,
  isHighlightJSUsed,
  useStraightLineInMermaid
) => {
  // Clear the output if there is any
  contents = [];

  // Disable the generate button and enable the stop button
  //   generateBtn.disabled = true;
  //   stopBtn.disabled = false;

  // Create a new AbortController instance
  let controller = modifyTheConroller(new AbortController());
  const signal = controller.signal;

  try {
    const response = await fetch(`https://www.onethreadapp.com/free-tools-server-express-test/`, {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        input: prompt,
        temperature,
      }),
      signal,
    });

    output.innerText = "";
    if (response.status === 429) {
      output.textContent =
        "You have reached the API limit. Please try again after a minute.";
      return;
    }

    // Read the response as a stream of data
    const reader = response.body.getReader();
    const decoder = new TextDecoder("utf-8");

    while (true) {
      const { done, value } = await reader.read();
      if (done) {
        break;
      }
      // Massage and parse the chunk of data
      const chunk = decoder.decode(value);
      const lines = chunk.split("\n");
      const parsedLines = lines
        .map((line) => line.replace(/^data: /, "").trim()) // Remove the "data: " prefix
        .filter((line) => line !== "" && line !== "[DONE]" && isJSON(line)) // Remove empty lines, non json values and "[DONE]"
        .map((line) => JSON.parse(line)); // Parse the JSON string

      for (const parsedLine of parsedLines) {
        const { choices } = parsedLine;
        const { delta } = choices[0];
        const { content } = delta;
        // Update the UI with the new content
        if (content) {
          output.classList.remove("empty");

          if (usingMermaidJS) {
            await handleUsingMermaid(content, useStraightLineInMermaid);
          }

          if (isResponseMarkdwown) {
            handleMarkdownResponse(content, isHighlightJSUsed);
          } else if (!usingMermaidJS) {
            output.textContent += content;
          }
        }
      }
    }
  } catch (error) {
    // Handle fetch request errors
    if (signal.aborted) {
      return;
    } else {
      console.error("Error:", error);
      output.innerText = "Error occurred while generating.";
    }
  } finally {
    // Enable the generate button and disable the stop button
    modifyTheConroller(null); // Reset the AbortController instance
  }
};

export default generate;
