import populateAboutArea from "../globaljs/populate-about-area.js";
import generateFAQ from "../globaljs/faqGenerator.js";

const aboutData = [
  [
    "What is a Job Title Generator?",
    `
    <p>At its core, a Job Title Generator is a dedicated tool that facilitates the crafting of unique and suitable job titles, leveraging a vast database enriched with knowledge spanning various industries, roles, and designations. It serves not just as an assistant, but as an expert guide steering you towards finding the ultimate title for any job position. Let's unearth the prominent features that set this tool apart:</p>
    <ul>
      <li><strong>Rich Database –</strong> Grounded in a substantial database, it ensures a wide array of title suggestions that are in sync with industry trends and specific role requirements.</li>
      <li><strong>Creativity and Precision –</strong> The generator brings to the table a unique combination of creativity and accuracy, promising titles that are not only catchy but also vividly portray the exact responsibilities associated with the job.</li>
      <li><strong>User-Friendly Interface –</strong> Designed with a user-friendly interface, it offers ease of navigation, making the task of finding the perfect job title as simple as a few clicks, suitable for both novices and experienced HR professionals.</li>
      <li><strong>Expert Guidance –</strong> It stands as a reliable partner, providing expert suggestions based on deep-seated knowledge of various sectors, aiding in the creation of titles that resonate with potential candidates.</li>
      <li><strong>No Prior Expertise Required –</strong> One of its standout features is its accessibility, which requires no previous expertise. It welcomes all users with open arms, insisting only on a clear understanding of the job role to churn out the best results.</li>
    </ul>
    `,
  ],
  [
    "Why Use a Job Title Generator?",
    `
    <p>Using a Job Title Generator isn't just about saving time; it's about upgrading the quality of your job listings. Here, we expand on its benefits:</p>
    <ul>
      <li><strong>Innovative Titles:</strong> Unleash a flood of creativity with titles that resonate with potential candidates, making them eager to learn more about the opportunities that await.</li>
      <li><strong>Time-Saver:</strong> Forget spending hours on brainstorming sessions. Get instant suggestions that are ready to grab attention.</li>
      <li><strong>SEO Advantages:</strong> Many generators are programmed to offer SEO-friendly suggestions, meaning your job posting could rank higher in job search results, attracting a larger pool of candidates.</li>
    </ul>
    `,
  ],
  [
    "How Job Title Generator Works",
    `
    <p>Diving deep into the operational aspects of a job title generator will reveal its prowess in simplifying the tedious task of crafting perfect job titles. Let’s break down the functioning of this indispensable tool step by step:</p>
    <ol>
      <li><strong>Step 1: Initialization</strong><br>Start your journey by providing essential details about the job role you're looking to fill. This information should include the core responsibilities, required skills, and the level of experience needed for the role.</li>
      <li><strong>Step 2: Intelligent Processing</strong><br>Here is where the magic happens. The generator employs complex algorithms and a vast database of industry-specific terminologies to analyze the details provided. It smartly combines these elements to create a list of potential job titles that are both creative and representative of the role.</li>
      <li><strong>Step 3: Output and Selection</strong><br>In a matter of seconds, you are presented with a curated list of job titles. This not only includes standard titles but also innovative ones that can make your job posting stand out in the crowded job market. Here, you have the opportunity to select a title that best resonates with the job description and the organization’s culture.</li>
      <li><strong>Step 4: Customization</strong><br>This stage offers the freedom to fine-tune the selected title to perfectly align with your job description. It ensures that the title is not just catchy but also gives a precise insight into what the role entails, setting clear expectations for potential candidates.</li>
      <li><strong>Step 5: Integration</strong><br>Once you are satisfied with the title, it’s time to integrate it into your job posting. The newly crafted title now stands ready to grab attention and attract the right candidates, becoming an integral part of your recruitment strategy.</li>
    </ol>
    `,
  ],
  [
    "How to Create a Job Title with This Generator",
    `
    <p>While the process is simple, understanding each step in detail will help you master the tool. Here’s a detailed walkthrough:</p>
    <ol>
      <li><strong>Step One:</strong> Launch the generator on a device of your choice, be it mobile, tablet, or desktop, and familiarize yourself with its features.</li>
      <li><strong>Step Two:</strong> As you input the job details, be specific and detailed to get the best results.</li>
      <li><strong>Step Three:</strong> With a simple click, initiate the generation process and wait for the magic to happen.</li>
      <li><strong>Step Four:</strong> Once presented with the options, take time to consider each before choosing the one that resonates the most with the role.</li>
      <li><strong>Step Five:</strong> Customization is key; don’t hesitate to add a personal touch to the generated title to make it your own truly.</li>
    </ol>
    `,
  ],
  [
    "Importance of Job Title",
    `
    <p>The weight that a well-chosen job title carries is immense. Let’s delve deeper:</p>
    <ul>
      <li><strong>Creating Impressions:</strong> Before reading the job description, candidates assess the role through the job title, which serves as a mini-description, encapsulating the role’s essence in a few words.</li>
      <li><strong>Depicting the Role Accurately:</strong> A well-articulated title can mirror the job’s core responsibilities, giving candidates a genuine insight into what awaits them.</li>
      <li><strong>SEO Play:</strong> Beyond just attracting candidates, an optimized job title plays a crucial role in ensuring the visibility of your post in the crowded online job marketplace.</li>
    </ul>
    `,
  ],
];


const faqData = [
  [
    "How effective is the Job Title Generator in attracting potential candidates?",
    "Absolutely! Our Job Title Generator is designed to craft titles that are both descriptive and captivating, significantly boosting the allure of your job listings and drawing in a broader range of candidates."
  ],
  [
    "Does the Job Title Generator cater to diverse sectors?",
    "Certainly. Our generator is versatile, tailored to understand and cater to the specific terminologies and nuances of various industries. This ensures that the titles generated are in line with industry standards, attracting the right talent."
  ],
  [
    "How accessible is the Job Title Generator for someone new to hiring?",
    "Designed with user experience in mind, our Job Title Generator is intuitive and straightforward, catering to both experienced recruiters and those new to the hiring process. Its structured design ensures a smooth and efficient title generation experience."
  ],
  [
    "Can I customize the titles suggested by the Job Title Generator?",
    "Of course! While our generator provides a range of apt titles based on your input, it also allows for customization. This ensures that the titles resonate with the specific job role and your company's ethos, adding a personal touch to your listings."
  ]
];

populateAboutArea(aboutData);
generateFAQ(faqData);
