import handleFormSubmit from "../globaljs/formSubmitHandler.js";

const getFormValues = () => {
  const projectType = document.querySelector("#projectType").value;
  const projectDescription = document.querySelector(
    "#projectDescription"
  ).value;
  const dependencies = document.querySelector("#dependencies").value;

  return {
    projectType,
    projectDescription,
    dependencies,
  };
};

const generatePrompt = (input) => {
  let prompt = `Act as a php code generator. Generate code for a PHP project of type ${input.projectType} that ${input.projectDescription}.`;

  if (input.dependencies) {
    prompt += ` Use the following dependencies: ${input.dependencies}`;
  }

  prompt += `
  ###Examples:
  user: Act as a php code generator. Generate code for a PHP project of type web application that creates a snake game.
  AI:
        <?php
        echo '
        <!DOCTYPE html>
        <html>
        <head>
            <title>Snake Game</title>
            <style>
                #game-board {
                    width: 400px;
                    height: 400px;
                    margin: 0 auto;
                    border: 1px solid #000;
                }
            </style>
        </head>
        <body>
            <h1>Snake Game</h1>
            <div id="game-board"></div>
            <script>
                // Snake Game logic in JavaScript

                // Initialize game variables
                var canvas = document.getElementById("game-board");
                var context = canvas.getContext("2d");
                var gridSize = 20;
                var snakeSize = 1;
                var snake = [{ x: gridSize, y: gridSize }];
                var food = { x: Math.floor(Math.random() * (canvas.width / gridSize)) * gridSize, y: Math.floor(Math.random() * (canvas.height / gridSize)) * gridSize };
                var direction = { x: gridSize, y: 0 };

                // Main game loop
                function gameLoop() {
                    clearCanvas();
                    moveSnake();
                    drawSnake();
                    drawFood();
                    requestAnimationFrame(gameLoop);
                }

                // Clear the canvas
                function clearCanvas() {
                    context.fillStyle = "#FFF";
                    context.fillRect(0, 0, canvas.width, canvas.height);
                }

                // Move the snake
                function moveSnake() {
                    var head = { x: snake[0].x + direction.x, y: snake[0].y + direction.y };
                    snake.unshift(head);
                    if (snake.length > snakeSize) {
                        snake.pop();
                    }
                }

                // Draw the snake
                function drawSnake() {
                    snake.forEach(function (segment) {
                        context.fillStyle = "#000";
                        context.fillRect(segment.x, segment.y, gridSize, gridSize);
                    });
                }

                // Draw the food
                function drawFood() {
                    context.fillStyle = "#F00";
                    context.fillRect(food.x, food.y, gridSize, gridSize);
                }

                // Handle keydown events to change direction
                document.addEventListener("keydown", function (event) {
                    if (event.keyCode === 37 && direction.x !== gridSize) {
                        direction = { x: -gridSize, y: 0 }; // left
                    }
                    if (event.keyCode === 38 && direction.y !== gridSize) {
                        direction = { x: 0, y: -gridSize }; // up
                    }
                    if (event.keyCode === 39 && direction.x !== -gridSize) {
                        direction = { x: gridSize, y: 0 }; // right
                    }
                    if (event.keyCode === 40 && direction.y !== -gridSize) {
                        direction = { x: 0, y: gridSize }; // down
                    }
                });

                // Start the game loop
                gameLoop();
            </script>
        </body>
        </html>
        ';
        ?>

    user: Act as a php code generator.Generate code for a PHP project of type command line tool that will take a directory path as an argument and print out all the files in that directory.
    AI:
    Sure! This script will take a directory path as an argument and print out all the files in that directory.

        #!/usr/bin/env php
        <?php
        if ($argc != 2) {
            echo "Usage: php " . $argv[0] . " <directory>\n";
            exit(1);
        }

        $dir = $argv[1];

        if (!is_dir($dir)) {
            echo "Error: " . $dir . " is not a directory.\n";
            exit(1);
        }

        $files = scandir($dir);

        foreach ($files as $file) {
            if ($file != '.' && $file != '..') {
                echo $file . "\n";
            }
        }
        ?>
        Here's how you can use this script:

        Save the script to a file, for example list_files.php.
        Make the script executable with the command chmod +x list_files.php.
        Run the script with a directory path as an argument, for example ./list_files.php /path/to/directory.
        The script will print out all the files in the specified directory.

        This script uses the scandir function to get an array of files in the specified directory, then it iterates over the array and prints out each file. It skips the '.' and '..' entries, which represent the current directory and the parent directory, respectively.
  `;

  prompt += "Give the response in markdown format.";
  return prompt;
};

const isResponseMarkdown = true;
const usingMermaidJS = false;
const temperature = 0;
const isHighlightJSUsed = true;

handleFormSubmit(
  getFormValues,
  generatePrompt,
  isResponseMarkdown,
  usingMermaidJS,
  temperature,
  isHighlightJSUsed
);
