import handleFormSubmit from "../globaljs/formSubmitHandler.js";

function getFormValues() {
  const companyName = document.getElementById("companyName").value;
  const projectDetails = document.getElementById("projectDetails").value;
  const language = document.getElementById("language").value;
  return {
    companyName,
    projectDetails,
    language,
  };
}

function generatePrompt() {
  const input = getFormValues();

  let prompt = `Act as a project proposal generator. Generate a project proposal for me in markdown format from the following informations:`;

  if (input.companyName) {
    prompt += `My company name: ${input.companyName}.`;
  }

  if (input.projectDetails) {
    prompt += `My project details: ${input.projectDetails}.`;
  }

  if (input.language) {
    prompt += `Create the proposal in ${input.language}.`;
  }

  prompt += `
  ###Use this template:
    # 💡 General Information
    The introduction sets the tone for your project proposal and should grab the reader's attention.
    - Introduce the project with a compelling headline
    - Provide an overview of the project and its objectives
    - State the problem your project aims to solve

    # 🌟 Value Proposition
    The value proposition is the core of your project proposal.
    - Identify the key features and benefits of the project
    - Describe how the project will address the problem statement
    - Explain the unique value the project offers compared to other solutions

    # 📈 Project Plan
    The project plan outlines the approach and timeline for executing the project.
    - Outline the project scope, including deliverables and timelines
    - Suggest the best methodology for the project
    - Identify the project team and their roles and responsibilities

    # 💰 Budget
    The budget section outlines the cost of executing the project.
    - Provide a detailed breakdown of the project budget, including all expenses
    - Explain how the project budget aligns with the project scope and objectives
    - Discuss any potential risks or challenges that may impact the project budget

    # 📊 Evaluation
    The evaluation section outlines how you will measure the success of the project.
    - Define the project success criteria and how they will be measured
    - Describe the evaluation methodology for measuring project success
    - Outline the reporting and communication plan for the project
  `;
  return prompt;
}

const isResponseMarkdown = true;
const usingMermaidJS = false;
const temperature = 0.5;

handleFormSubmit(
  getFormValues,
  generatePrompt,
  isResponseMarkdown,
  usingMermaidJS,
  temperature
);
