const form = document.getElementById("sitemapForm");

const cleanCodeOutputArea = () => {
  document.getElementById("codeOutput").innerHTML = ""; // Clear the output if there is any
  document.getElementById("codeOutput").classList.remove("empty");
  document.getElementById("codeOutput").style.display = "block";
};

const showResponseFromServer = async (siteUrl) => {
  try {
    const response = await fetch("http://localhost:3000/", {
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({ siteUrl: siteUrl }),
      method: "POST",
    });

    if (!response.ok) {
      throw new Error(response.status);
    }

    const reader = response.body.getReader();
    const decoder = new TextDecoder("utf-8");

    cleanCodeOutputArea();

    while (true) {
      const { done, value } = await reader.read();
      if (done) {
        document.getElementById("codeOutput").textContent += `
        </urlset>
        `;
        break;
      }
      // parse the chunk of data
      const chunk = decoder.decode(value);
      const lines = chunk.split("\n");
      const uniqueUrl = lines[lines.length - 2];
      // we are getting stream of chunks from server
      // each chunk contains a new url and all the previous url that were sent from server
      // so we need to get the second last item from the chunk to get the new url
      // we are getting second last item becuase the last item of the lines array is empty string

      if (document.getElementById("codeOutput").innerHTML === "") {
        document.getElementById(
          "codeOutput"
        ).textContent = `<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
            <urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">`;
      }

      document.getElementById("codeOutput").textContent += `
            <url>
              <loc>${uniqueUrl}</loc>
            </url>`;
    }

    hljs.highlightAll();
    // this is added after the loop (after user gets the full sitemap) to optimize the performance
  } catch (err) {
    if (err.message === "404") {
      document.getElementById("codeOutput").textContent =
        "Something went wrong. Please try with a different URL.";
    } else {
      document.getElementById("codeOutput").textContent =
        "Something went wrong.";
    }
  }
};

form.onsubmit = async function (e) {
  e.preventDefault();

  const generateBtn = document.querySelector("#generate");
  const generateBtnLoadingSvg = document.querySelector("#generate svg");
  generateBtnLoadingSvg.classList.remove("hidden");
  generateBtn.disabled = true;

  const siteUrl = document.getElementById("url").value;
  await showResponseFromServer(siteUrl);

  generateBtnLoadingSvg.classList.add("hidden");
  generateBtn.disabled = false;
};
