let svg = `
<svg width="13" height="7" viewBox="0 0 13 7" fill="none"><path d="M1.75 1L6.75 6L11.75 1" stroke="#475467" stroke-width="1.67" stroke-linecap="round" stroke-linejoin="round"></path></svg>
`;

const megaMenu = document.createElement("div");
const megaMenuSections = [
  {
    name: "Blog",
    content: "Read how to manage projects in easy way.",
    link: "https://www.onethreadapp.com/blog/",
  },
  {
    name: "User Guide",
    content: "All the tools you need to get started with Onethread.",
    link: "https://docs.onethread.app/",
  },
  {
    name: "Developers Guideline",
    content: "Learn and build your app with Onethread.",
    link: "https://www.onethreadapp.com/api-documentation",
  },
];

const megaMenuIcons = [
  {
    name: "Blog",
    img: "https://uploads-ssl.webflow.com/6406002a88679e7df96b5098/64e4166e59df87be196baea3_check-circle.svg",
  },
  {
    name: "User Guide",
    img: "https://uploads-ssl.webflow.com/6406002a88679e7df96b5098/64e41cc6f36f56d909429c20_grid_on.svg",
  },
  {
    name: "Developers Guideline",
    img: "https://uploads-ssl.webflow.com/6406002a88679e7df96b5098/64e41c5d1feba79c997f517a_inventory_2.svg",
  },
];

const anchors = [
  {
    name: "Features",
    link: "https://www.onethreadapp.com/features",
  },
  {
    name: "Resources",
  },
  {
    name: "Pricing",
    link: "https://www.onethreadapp.com/pricing",
  },
  {
    name: "Contact Us",
    link: "https://www.onethreadapp.com/contact-us",
  },
  {
    name: "Book a Demo",
    link: "https://www.onethreadapp.com/book-session",
  },
  {
    name: "AI Tools",
    link: "https://www.onethreadapp.com/free-tools",
  },
];

const createDesktopNav = () => {
  let desktopDropdownContainer = document.createElement("div");
  desktopDropdownContainer.classList.add("resources-dropdown-container");

  const allSectionContainerDesktop = document.createElement("div");
  allSectionContainerDesktop.classList.add("all-section-container", "hidden");

  megaMenuSections.forEach((section) => {
    const sectionContainer = document.createElement("a");
    sectionContainer.href = section.link;
    sectionContainer.classList.add("section-container");
    const sectionContentContainer = document.createElement("div");
    sectionContentContainer.classList.add("section-content-container");

    const h4 = document.createElement("h4");
    const paragraph = document.createElement("p");
    const img = document.createElement("img");

    h4.textContent = section.name;
    paragraph.textContent = section.content;

    if (section.name === "Blog") {
      img.src = megaMenuIcons[0].img;
    }
    if (section.name === "User Guide") {
      img.src = megaMenuIcons[1].img;
    }
    if (section.name === "Developers Guideline") {
      img.src = megaMenuIcons[2].img;
    }

    sectionContentContainer.appendChild(h4);
    sectionContentContainer.appendChild(paragraph);
    sectionContainer.appendChild(img);
    sectionContainer.appendChild(sectionContentContainer);
    allSectionContainerDesktop.appendChild(sectionContainer);
  });

  const signUpBtn = document.createElement("a");
  signUpBtn.target = "_blank";
  signUpBtn.href = "https://app.onethread.app/signup";
  signUpBtn.id = "sign-up-btn";
  signUpBtn.textContent = "Create Free Account";

  const logInButton = document.createElement("a");
  logInButton.target = "_blank";
  logInButton.href = "https://app.onethread.app/signin";
  logInButton.id = "log-in-button";
  logInButton.textContent = "Log In";

  // Create main div
  let div = document.createElement("div");
  div.id = "nav-links-area";

  const desktopOtLogo = document.createElement("a");
  desktopOtLogo.id = "ot-logo-link";
  desktopOtLogo.href = "https://www.onethreadapp.com/";
  desktopOtLogo.areaCurrent = "page";
  desktopOtLogo.innerHTML = `
      <img id='logo' src='https://uploads-ssl.webflow.com/6406002a88679e7df96b5098/64e0b51a9521a23149a73036_logo.svg' alt='OneThread logo'>
   `;
  div.appendChild(desktopOtLogo);

  anchors.forEach((obj) => {
    let a = document.createElement("a");
    a.href = obj.link;
    a.textContent = obj.name;
    if (obj.name === "Resources") {
      const resourcesDiv = document.createElement("div");
      resourcesDiv.textContent = obj.name;
      desktopDropdownContainer.innerHTML = svg;
      desktopDropdownContainer.insertBefore(
        resourcesDiv,
        desktopDropdownContainer.children[0]
      );
      div.appendChild(desktopDropdownContainer);
    } else {
      div.appendChild(a);
    }
  });

  const authButtonsContainer = document.createElement("div");
  authButtonsContainer.id = "auth-buttons-container";

  authButtonsContainer.appendChild(signUpBtn);
  authButtonsContainer.appendChild(logInButton);

  const navContainer = document.querySelector("nav");
  const nav = document.createElement("div");
  nav.classList.add("desktop-nav");
  nav.appendChild(div);
  nav.appendChild(authButtonsContainer);

  navContainer.appendChild(nav);
  navContainer.appendChild(allSectionContainerDesktop);
};

createDesktopNav();

const createMobileNav = () => {
  const mobileNavContainer = document.querySelector("nav");
  mobileNavContainer.classList.add("mobile-nav-container");
  const mobileNav = document.createElement("div");
  mobileNav.classList.add("mobile-nav");

  const mobileOtLogo = document.createElement("a");
  mobileOtLogo.id = "ot-logo-link";
  mobileOtLogo.href = "https://www.onethreadapp.com/";
  mobileOtLogo.areaCurrent = "page";
  mobileOtLogo.innerHTML = `
      <img id='logo' src='https://uploads-ssl.webflow.com/6406002a88679e7df96b5098/64e0b51a9521a23149a73036_logo.svg' alt='OneThread logo'>
   `;
  mobileNav.appendChild(mobileOtLogo);

  let hamburger = document.createElement("div");
  hamburger.classList.add("hamburger");
  hamburger.innerHTML = `
    <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 100 100" width="30" height="30" style="width: 100%; height: 100%;" preserveAspectRatio="xMidYMid meet"><defs><clipPath id="__lottie_element_2"><rect width="100" height="100" x="0" y="0"></rect></clipPath></defs><g clip-path="url(#__lottie_element_2)"><g style="display: block;" transform="matrix(1,0,0,1,51,30)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(1,0,0,1,51,50)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(1,0,0,1,51,70)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g></g></svg>`;
  mobileNav.appendChild(hamburger);

  mobileNavContainer.appendChild(mobileNav);

  const allSectionContainerMobile = document.createElement("div");

  megaMenuSections.forEach((section) => {
    const sectionContainer = document.createElement("a");
    sectionContainer.href = section.link;
    sectionContainer.classList.add("section-container");
    const sectionContentContainer = document.createElement("div");
    sectionContentContainer.classList.add("section-content-container");

    const h4 = document.createElement("h4");
    const paragraph = document.createElement("p");
    const img = document.createElement("img");

    h4.textContent = section.name;
    paragraph.textContent = section.content;

    if (section.name === "Blog") {
      img.src = megaMenuIcons[0].img;
    }
    if (section.name === "User Guide") {
      img.src = megaMenuIcons[1].img;
    }
    if (section.name === "Developers Guideline") {
      img.src = megaMenuIcons[2].img;
    }

    sectionContentContainer.appendChild(h4);
    sectionContentContainer.appendChild(paragraph);
    sectionContainer.appendChild(img);
    sectionContainer.appendChild(sectionContentContainer);
    allSectionContainerMobile.appendChild(sectionContainer);
  });

  const dropdownContentContainer = document.createElement("div");
  dropdownContentContainer.classList.add("resources-dropdown-container");
  allSectionContainerMobile.classList.add(
    "responsive-all-section-container",
    "hidden"
  );

  const mobileNavChilds = document.createElement("div");
  mobileNavChilds.classList.add("mobile-nav-childs");

  anchors.forEach((obj) => {
    let a = document.createElement("a");
    a.href = obj.link;
    a.textContent = obj.name;
    if (obj.name === "Resources") {
      const resourcesDiv = document.createElement("div");
      resourcesDiv.textContent = obj.name;
      dropdownContentContainer.innerHTML = svg;
      dropdownContentContainer.insertBefore(
        resourcesDiv,
        dropdownContentContainer.children[0]
      );
      mobileNavChilds.appendChild(dropdownContentContainer);
      mobileNavChilds.appendChild(allSectionContainerMobile);
    } else {
      mobileNavChilds.appendChild(a);
    }
  });

  const mobileSignUpBtn = document.createElement("a");
  mobileSignUpBtn.target = "_blank";
  mobileSignUpBtn.href = "https://app.onethread.app/signup";
  mobileSignUpBtn.id = "sign-up-btn";
  mobileSignUpBtn.textContent = "Create My Free Account";

  const mobileLogInButton = document.createElement("a");
  mobileLogInButton.target = "_blank";
  mobileLogInButton.href = "https://app.onethread.app/signin";
  mobileLogInButton.id = "log-in-button";
  mobileLogInButton.textContent = "Log In";

  mobileSignUpBtn.classList.add("mobile-sign-up-button");
  mobileLogInButton.classList.add("mobile-log-in-button");

  mobileNavChilds.appendChild(mobileSignUpBtn);
  mobileNavChilds.appendChild(mobileLogInButton);

  mobileNavContainer.appendChild(mobileNavChilds);

  hamburger.addEventListener("click", () => {
    hamburger.classList.toggle("x-icon");

    if (hamburger.classList.contains("x-icon")) {
      mobileNav.style.borderRadius = "8px 8px 0px 0px";

      hamburger.innerHTML =
        '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 100 100" width="30" height="30" style="width: 100%; height: 100%;" preserveAspectRatio="xMidYMid meet"><defs><clipPath id="__lottie_element_2"><rect width="100" height="100" x="0" y="0"></rect></clipPath></defs><g clip-path="url(#__lottie_element_2)"><g style="display: block;" transform="matrix(0.7071067690849304,-0.7071067690849304,0.7071067690849304,0.7071067690849304,51,50)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(0.7071067690849304,0.7071067690849304,-0.7071067690849304,0.7071067690849304,51,50)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(0.7071067690849304,-0.7071067690849304,0.7071067690849304,0.7071067690849304,51,50)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g></g></svg>';

      mobileNavChilds.style.display = "flex";
    } else {
      mobileNav.style.borderRadius = "8px";

      hamburger.innerHTML =
        '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 100 100" width="30" height="30" style="width: 100%; height: 100%;" preserveAspectRatio="xMidYMid meet"><defs><clipPath id="__lottie_element_2"><rect width="100" height="100" x="0" y="0"></rect></clipPath></defs><g clip-path="url(#__lottie_element_2)"><g style="display: block;" transform="matrix(1,0,0,1,51,30)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(1,0,0,1,51,50)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g><g style="display: block;" transform="matrix(1,0,0,1,51,70)" opacity="1"><g opacity="1" transform="matrix(2,0,0,2,0,0)"><path fill="rgb(51,51,51)" fill-opacity="1" d=" M15.5,0 C15.5,0 15.5,0 15.5,0 C15.5,1.1038000583648682 14.603799819946289,2 13.5,2 C13.5,2 -13.5,2 -13.5,2 C-14.603799819946289,2 -15.5,1.1038000583648682 -15.5,0 C-15.5,0 -15.5,0 -15.5,0 C-15.5,-1.1038000583648682 -14.603799819946289,-2 -13.5,-2 C-13.5,-2 13.5,-2 13.5,-2 C14.603799819946289,-2 15.5,-1.1038000583648682 15.5,0z"></path></g></g></g></svg>';
    }
    setTimeout(() => {
      mobileNavChilds.classList.toggle("show-dropdown");
    }, 0);

    if (!hamburger.classList.contains("x-icon")) {
      setTimeout(() => {
        mobileNavChilds.style.display = "none";
      }, 200);
    }
  });
};
createMobileNav();

const dropdownContainers = document.querySelectorAll(
  ".resources-dropdown-container"
);

dropdownContainers.forEach((container) => {
  container.addEventListener("click", () => {
    const allSectionContainer = document.querySelector(
      ".all-section-container"
    );

    const responsiveAllSectionContainer = document.querySelector(
      ".responsive-all-section-container"
    );
    const desktopNav = document.querySelector(".desktop-nav");

    const desktopNavDisplayStyle = window.getComputedStyle(desktopNav).display;
    if (desktopNavDisplayStyle !== "none") {
      allSectionContainer.classList.toggle("hidden");

      if (
        allSectionContainer.classList.contains("hidden") &&
        !desktopNav.classList.contains("nav-in-top")
      ) {
        allSectionContainer.parentElement.children[0].style.borderRadius =
          "12px";
      } else {
        allSectionContainer.parentElement.children[0].style.borderRadius =
          "12px 12px 0px 0px";
      }
    } else {
      responsiveAllSectionContainer.classList.toggle("hidden");

      if (!responsiveAllSectionContainer.classList.contains("hidden")) {
        responsiveAllSectionContainer.style.maxHeight = "400px";
      } else if (responsiveAllSectionContainer.classList.contains("hidden")) {
        responsiveAllSectionContainer.style.maxHeight = "0px";
      }
    }
  });
});
