import populateAboutArea from "../globaljs/populate-about-area.js";
import generateFAQ from "../globaljs/faqGenerator.js";

const aboutData = [
  [
    "What is a Haiku Generator?",
    `
    <p>A Haiku Generator is a dynamic tool that simplifies the process of crafting haikus, ensuring that both beginners and seasoned poets can create enchanting verses. Here are the key features:</p>
    <ul>
      <li><strong>Instant Creativity:</strong> The Haiku Generator sparks creativity by offering suggestions and guidance for composing haikus.</li>
      <li><strong>Syllable Structure:</strong> It helps maintain the traditional 5-7-5 syllable structure of haikus, ensuring adherence to this poetic form's conventions.</li>
      <li><strong>Inspiration at Your Fingertips:</strong> With its vast database of words and themes, it provides an abundance of ideas to ignite your poetic imagination.</li>
    </ul>
    `,
  ],
  [
    "Why Use a Haiku Generator?",
    `
    <p>Let's explore the reasons why incorporating a Haiku Generator into your poetic endeavors is a game-changer:</p>
    <ul>
      <li><strong>Overcoming Writer's Block:</strong> Poet's block is a common challenge. The Haiku Generator provides inspiration and ideas when you're stuck for words.</li>
      <li><strong>Syllable Perfection:</strong> Maintaining the 5-7-5 syllable structure of a haiku can be tricky. The generator ensures your haikus adhere to this traditional format.</li>
      <li><strong>Efficiency in Creation:</strong> Creating haikus manually can be time-consuming. The generator streamlines the process, allowing you to compose more haikus in less time.</li>
      <li><strong>Enhanced Creativity:</strong> By suggesting words, themes, and structures, the Haiku Generator encourages creative exploration, helping you craft unique and memorable verses.</li>
    </ul>
    `,
  ],
  [
    "How Haiku Generator Works?",
    `
    <p>Understanding the inner workings of a Haiku Generator can demystify the poetry creation process. Here's a detailed breakdown of how it operates:</p>
    <ol>
      <li><strong>Define the Theme</strong> - Begin by providing the Haiku Generator with a topic or theme. Whether it's "spring blossoms" or "winter chills", this initial input gives the tool a direction for your poetic creation.</li>
      <li><strong>Analyzing Syllables</strong> - Haikus have a specific 5-7-5 syllable pattern across three lines. The generator, equipped with a vast lexical database, selects words that fit this unique structure, ensuring the poem adheres to traditional haiku guidelines.</li>
      <li><strong>Natural Language Processing (NLP)</strong> - Utilizing NLP, the tool comprehends the emotional and contextual undertones of the theme you've provided. This allows it to craft a haiku that's not only structurally correct but also evocative and thematically consistent.</li>
      <li><strong>Generating the Haiku</strong> - The software now combines its understanding of the theme with its lexical knowledge. It crafts a three-line poem, ensuring the lines flow seamlessly while maintaining the 5-7-5 syllable structure.</li>
      <li><strong>Review and Refine</strong> - Once generated, you have the opportunity to review the haiku. If it doesn't quite capture the essence you were aiming for, many generators allow for slight tweaks or a complete regeneration of the poem.</li>
      <li><strong>Export and Share</strong> - With a haiku you're satisfied with, the tool will usually offer options to save, export, or even share your creation directly to social media. Spread your poetic wings and let the world admire your digitally-assisted craftsmanship!</li>
    </ol>
    `,
  ],
  [
    "How to Create Haikus With This Generator",
    `
    <p>Crafting haikus with a Haiku Generator is an accessible and straightforward process. Here's how you can create enchanting haikus:</p>
    <ol>
      <li><strong>Choose Your Theme</strong> - Begin by selecting a theme, keyword, or concept that you'd like your haiku to center around. This provides the generator with a creative starting point.</li>
      <li><strong>Generate Suggestions</strong> - Click the "Generate" button, and watch as the Haiku Generator generates a list of potential haikus based on your chosen theme and syllable structure.</li>
      <li><strong>Select and Refine</strong> - Browse through the suggested haikus and select the ones that resonate with your vision. You can then further refine and customize them to add your unique touch.</li>
      <li><strong>Share Your Haikus</strong> - Once you're satisfied with your haikus, share them with the world through social media, poetry communities, or personal blogs to captivate and inspire others.</li>
    </ol>
    `,
  ],
  [
    "Importance of Haikus in Poetry",
    `
    <p>Haikus hold a special place in the world of poetry. Here's why they are of utmost significance:</p>
    <ul>
      <li><strong>Concise Beauty:</strong> Haikus distill complex emotions and imagery into a few lines, showcasing the power of brevity in poetic expression.</li>
      <li><strong>Aesthetic Impact:</strong> The 5-7-5 syllable structure forces poets to carefully select and arrange words, resulting in verses with profound aesthetic impact.</li>
      <li><strong>Cultural Heritage:</strong> Haikus have a rich cultural history, originating from Japan and carrying traditions and symbolism that add depth to their meaning.</li>
      <li><strong>Universal Appeal:</strong> Haikus resonate across cultures and languages, making them a universally appreciated form of poetry.</li>
    </ul>
    `,
  ],
];

const aboutDataHeading = `
<p>What if you could capture a moment's essence with just a few words? Enter the Haiku Generator, a tool that crafts these brief, poetic snapshots for you. Haikus are traditional Japanese poems with a 5-7-5 syllable structure. They often reflect nature and emotions.</p>
<p>The Haiku Generator simplifies creativity. It selects words that fit the haiku format. This tool is part of Onethread's Free Tools List. It's designed for ease and inspiration.</p>
<p>With a click, you transform thoughts into poetry. No need for a poetic touch; the generator handles that. It's like a friend who whispers just the right words. Try it, and watch your ideas bloom into haiku.</p>

`

const faqData = [
  [
    "Do I need prior poetic experience to use the Haiku Generator?",
    "Not at all! Our Haiku Generator is designed to cater to everyone, from novices to seasoned poets, making the art of haiku creation accessible to all."
  ],
  [
    "Can I tweak the haikus produced by the Haiku Generator?",
    "Certainly! Our generator provides a foundation, but you're free to modify and personalize the haikus to resonate with your unique voice and style."
  ],
  [
    "Are there restrictions on the themes or keywords I can introduce into the Haiku Generator?",
    "Our Haiku Generator is versatile, accommodating a broad spectrum of themes and keywords. However, for best results, it's advisable to input relevant and clear concepts."
  ],
  [
    "Am I allowed to share the haikus I craft with the Haiku Generator on various platforms?",
    "Of course! Feel free to share your creations on social media, poetry communities, or any platform of your choice. We're here to help you express and inspire!"
  ]
];

populateAboutArea(aboutData,aboutDataHeading);
generateFAQ(faqData);
