import createOutputActions from "../globaljs/createOutputActionsForVisuals.js";
import createDownloadFunctionalityForFlowchart from "../globaljs/downloadFlowChart.js";

const nodes = [];
const edges = [];

const output = document.querySelector("#output");
const form = document.querySelector("form");

form.onsubmit = function (e) {
  e.preventDefault();
  output.classList.remove("empty");
  output.textContent = "";
  output.removeAttribute("id");
  output.id = "cy";

  const source = document.querySelector("#source").value;
  const target = document.querySelector("#target").value;
  const type = document.querySelector("#type").value;

  if (!source || !target || !type) {
    output.textContent = "Please fill up the form properly.";
    output.classList.add("empty");

    return;
  }

  nodes.push({
    data: {
      id: source,
    },
  });

  nodes.push({
    data: {
      id: target,
    },
  });

  edges.push({
    data: {
      id: edges.length,
      source: source,
      target: target,
      label: type,
    },
  });

  try {
    const cy = cytoscape({
      container: document.getElementById("cy"),
      elements: {
        nodes: nodes,
        edges: edges,
      },
      style: [
        {
          selector: "node",
          style: {
            "text-valign": "center",
            "text-halign": "center",
            "text-outline-width": 2,
            "text-outline-color": "#888",
            "background-color": "#888",
            label: "data(id)",
            width: 100,
            height: 100,
          },
        },
        {
          selector: "edge",
          style: {
            width: 5,
            "text-outline-width": 2,
            "text-outline-color": "#888",
            "background-color": "#888",
            "line-color": "light grey",
            "target-arrow-color": "grey",
            "target-arrow-shape": "triangle",
            "curve-style": "bezier",
            label: "data(label)",
          },
        },
      ],
    });

    cy.layout({
      name: "cose",
    }).run();

    const graph = document.querySelector("#cy");

    createOutputActions(graph);
  } catch (err) {
    output.textContent = err.message;
    output.classList.add("empty");
  }
};
